Crate airis

Crate airis 

Structs

AirsError
BatchNorm
ConvolutionConfig
ConvolutionND
LeakyRelu
ParametricRelu
RandomizedRelu
Relu
Sigmoid
Tensor
VariableName
A variable store with an associated path for variables naming.
VariableStore
A VarStore is used to store variables used by one or multiple layers. It specifies a single device where all variables are stored.

Enums

AirsErrorKind
DataType
Device

Constants

VARIABLE_NAME_SEPARATOR

Traits

Layer
TensorExtension

Type Aliases

AirsResult
Convolution1D
Convolution2D
Convolution3D