Structs
- Airs
Error - Batch
Norm - Convolution
Config - ConvolutionND
- Leaky
Relu - Parametric
Relu - Randomized
Relu - Relu
- Sigmoid
- Tensor
- Variable
Name - A variable store with an associated path for variables naming.
- Variable
Store - A VarStore is used to store variables used by one or multiple layers. It specifies a single device where all variables are stored.